@@ -28,6 +28,7 @@ import proxysupport
 import httpurl
 import internpaturl
 import linkcheck.ftpparse._ftpparse as ftpparse
+from const import WARN_FTP_MISSING_SLASH
 
 DEFAULT_TIMEOUT_SECS = 300
 
@@ -110,7 +111,6 @@ class FtpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
             raise linkcheck.LinkCheckerError(
                    _("Remote host has closed connection: %r") % msg)
         if not self.url_connection.getwelcome():
-            self.close_connection()
             raise linkcheck.LinkCheckerError(
                    _("Got no answer from FTP server"))
         # don't set info anymore, this may change every time we log in
@@ -146,7 +146,7 @@ class FtpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
             if not self.url.endswith('/'):
                 self.add_warning(
                          _("Missing trailing directory slash in ftp url."),
-                         tag="ftp-missing-slash")
+                         tag=WARN_FTP_MISSING_SLASH)
                 self.url += '/'
             return
         raise ftplib.error_perm("550 File not found")
@@ -180,7 +180,7 @@ class FtpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
         """
         See if URL target is a HTML file by looking at the extension.
         """
-        if linkcheck.checker.extensions['html'].search(self.url):
+        if linkcheck.checker.const.extensions['html'].search(self.url):
             return True
         return False
 
@@ -190,7 +190,7 @@ class FtpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
         """
         if self.is_directory():
             return True
-        for ro in linkcheck.checker.extensions.itervalues():
+        for ro in linkcheck.checker.const.extensions.itervalues():
             if ro.search(self.url):
                 return True
         return False
@@ -208,7 +208,7 @@ class FtpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
         if self.is_directory():
             self.parse_html()
             return
-        for key, ro in linkcheck.checker.extensions.iteritems():
+        for key, ro in linkcheck.checker.const.extensions.iteritems():
             if ro.search(self.url):
                 getattr(self, "parse_"+key)()
 
@@ -219,7 +219,7 @@ class FtpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
         """
         if not self.valid:
             return ""
-        if self.has_content:
+        if self.data is not None:
             return self.data
         t = time.time()
         if self.is_directory():
@@ -238,7 +238,6 @@ class FtpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
             buf.close()
         self.dltime = time.time() - t
         self.dlsize = len(self.data)
-        self.has_content = True
         return self.data
 
     def close_connection (self):
