@@ -35,6 +35,11 @@ import linkcheck.httplib2
 import httpheaders as headers
 import internpaturl
 import proxysupport
+# import warnings
+from const import WARN_HTTP_ROBOTS_DENIED, WARN_HTTP_NO_ANCHOR_SUPPORT, \
+    WARN_HTTP_WRONG_REDIRECT, WARN_HTTP_MOVED_PERMANENT, \
+    WARN_HTTP_EMPTY_CONTENT, WARN_HTTP_COOKIE_STORE_ERROR, \
+    WARN_HTTP_DECOMPRESS_ERROR, WARN_HTTP_UNSUPPORTED_ENCODING
 
 # helper alias
 unicode_safe = linkcheck.strformat.unicode_safe
@@ -163,7 +168,7 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
             # remove all previously stored results
             self.add_warning(
                        _("Access denied by robots.txt, checked only syntax."),
-                       tag="http-robots-denied")
+                       tag=WARN_HTTP_ROBOTS_DENIED)
             self.set_result(u"syntax OK")
             return
         # check for amazon server quirk
@@ -186,7 +191,7 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
         if self.no_anchor:
             self.add_warning(_("Server %r had no anchor support, removed"
                                " anchor from request.") % server,
-                             tag="http-no-anchor-support")
+                             tag=WARN_HTTP_NO_ANCHOR_SUPPORT)
         # redirections might have changed the URL
         newurl = urlparse.urlunsplit(self.urlparts)
         if self.url != newurl:
@@ -288,7 +293,7 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
                 mime = headers.get_content_type(self.headers)
                 poweredby = self.headers.get('X-Powered-By', '')
                 server = self.headers.get('Server', '')
-                if mime == 'application/octet-stream' and \
+                if mime in ('application/octet-stream', 'text/plain') and \
                   (poweredby.startswith('Zope') or server.startswith('Zope')):
                     # Zope server could not get Content-Type with HEAD
                     self.method = "GET"
@@ -315,8 +320,7 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
             newurl = unicode_safe(newurl)
             assert None == linkcheck.log.debug(linkcheck.LOG_CHECK,
                 "Redirected to %r", newurl)
-            self.add_info(_("Redirected to %(url)s.") % {'url': newurl},
-                          tag="http-redirect")
+            self.add_info(_("Redirected to %(url)s.") % {'url': newurl})
             # norm base url - can raise UnicodeError from url.idna_encode()
             redirected, is_idn = linkcheck.checker.urlbase.url_norm(newurl)
             assert None == linkcheck.log.debug(linkcheck.LOG_CHECK,
@@ -337,7 +341,7 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
                     self.add_warning(
                        _("Access to redirected URL denied by robots.txt, "
                          "checked only syntax."),
-                       tag="http-robots-denied")
+                       tag=WARN_HTTP_ROBOTS_DENIED)
                     self.set_result(u"syntax OK")
                 return -1, response
             # see about recursive redirect
@@ -364,7 +368,7 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
                         self.add_warning(
                            _("HTTP 301 (moved permanent) encountered: you"
                              " should update this link."),
-                           tag="http-moved-permanent")
+                           tag=WARN_HTTP_MOVED_PERMANENT)
                     self.has301status = True
             # check cache again on the changed URL
             if self.aggregate.urlqueue.checked_redirect(redirected, self):
@@ -375,12 +379,11 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
                     self.add_warning(
                            _("Redirection to different URL type encountered; "
                              "the original URL was %r.") % self.url,
-                           tag="http-wrong-redirect")
+                           tag=WARN_HTTP_WRONG_REDIRECT)
                 newobj = linkcheck.checker.get_url_from(
                           redirected, self.recursion_level, self.aggregate,
                           parent_url=self.parent_url, base_ref=self.base_ref,
-                          line=self.line, column=self.column, name=self.name,
-                          assume_local=False)
+                          line=self.line, column=self.column, name=self.name)
                 # append new object to queue
                 self.aggregate.urlqueue.put(newobj)
                 # pretend to be finished and logged
@@ -414,7 +417,7 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
             if response.status == 204:
                 # no content
                 self.add_warning(unicode_safe(response.reason),
-                                 tag="http-empty-content")
+                                 tag=WARN_HTTP_EMPTY_CONTENT)
             # store cookies for valid links
             if self.aggregate.config['storecookies']:
                 for c in self.cookies:
@@ -429,7 +432,7 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
                 except Cookie.CookieError, msg:
                     self.add_warning(_("Could not store cookies: %(msg)s.") %
                                      {'msg': str(msg)},
-                                     tag="http-cookie-store-error")
+                                     tag=WARN_HTTP_COOKIE_STORE_ERROR)
             if response.status >= 200:
                 self.set_result(u"%r %s" % (response.status, response.reason))
             else:
@@ -450,8 +453,8 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
             scheme = self.urlparts[0]
         assert None == linkcheck.log.debug(linkcheck.LOG_CHECK,
             "Connecting to %r", host)
-        if self.url_connection:
-            self.close_connection()
+        # close/release a previous connection
+        self.close_connection()
         self.url_connection = self.get_http_object(host, scheme)
         if self.no_anchor:
             anchor = ''
@@ -494,9 +497,13 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
                 self.url_connection.putheader(name, value)
         self.url_connection.endheaders()
         response = self.url_connection.getresponse()
-        self.persistent = not response.will_close
         self.timeout = headers.http_timeout(response)
         self.headers = response.msg
+        self.persistent = not response.will_close
+        if self.persistent and (self.method == "GET" or
+           self.headers.getheader("Content-Length", "")):
+            # always read content from persistent connections
+            self._read_content(response)
         # If possible, use official W3C HTTP response name
         if response.status in httpresponses:
             response.reason = httpresponses[response.status]
@@ -541,34 +548,39 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
         @return: URL content, decompressed and decoded
         @rtype: string
         """
-        if not self.has_content:
+        if self.data is None:
             self.method = "GET"
-            self.close_connection()
-            t = time.time()
             response = self._get_http_response()
             tries, response = self.follow_redirections(response,
                                                        set_result=False)
             self.headers = response.msg
-            self.data = response.read()
-            encoding = headers.get_content_encoding(self.headers)
-            if encoding in _supported_encodings:
-                try:
-                    if encoding == 'deflate':
-                        f = StringIO.StringIO(zlib.decompress(self.data))
-                    else:
-                        f = linkcheck.gzip2.GzipFile('', 'rb', 9,
-                                          StringIO.StringIO(self.data))
-                except zlib.error, msg:
-                    self.add_warning(_("Decompress error %(err)s") %
-                                     {"err": str(msg)},
-                                     tag="http-decompress-error")
-                    f = StringIO.StringIO(self.data)
-                self.data = f.read()
-            self.downloadtime = time.time() - t
-            response.close()
-            self.has_content = True
+            self._read_content(response)
+            if self.data is None:
+                self.data = ""
         return self.data
 
+    def _read_content (self, response):
+        t = time.time()
+        data = response.read()
+        encoding = headers.get_content_encoding(self.headers)
+        if encoding in _supported_encodings:
+            try:
+                if encoding == 'deflate':
+                    f = StringIO.StringIO(zlib.decompress(data))
+                else:
+                    f = linkcheck.gzip2.GzipFile('', 'rb', 9,
+                                      StringIO.StringIO(data))
+            except zlib.error, msg:
+                self.add_warning(_("Decompress error %(err)s") %
+                                 {"err": str(msg)},
+                                 tag=WARN_HTTP_DECOMPRESS_ERROR)
+                f = StringIO.StringIO(data)
+            data = f.read()
+        if self.data is None and self.method == "GET" and \
+           response.status not in [301, 302]:
+            self.data = data
+            self.dltime = time.time() - t
+
     def is_html (self):
         """
         See if this URL points to a HTML file by looking at the
@@ -585,7 +597,7 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
         if encoding and encoding not in _supported_encodings and \
            encoding != 'identity':
             self.add_warning(_('Unsupported content encoding %r.') % encoding,
-                             tag="http-unsupported-encoding")
+                             tag=WARN_HTTP_UNSUPPORTED_ENCODING)
             return False
         return True
 
@@ -614,7 +626,7 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
         if encoding and encoding not in _supported_encodings and \
            encoding != 'identity':
             self.add_warning(_('Unsupported content encoding %r.') % encoding,
-                             tag="http-unsupported-encoding")
+                             tag=WARN_HTTP_UNSUPPORTED_ENCODING)
             return False
         return True
 
@@ -649,8 +661,8 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
         _user, _password = self.get_user_password()
         key = ("http", self.urlparts[1], _user, _password)
         if self.persistent and self.url_connection.is_idle():
-            cache_add = self.aggregate.connections.add
-            cache_add(key, self.url_connection, self.timeout)
+            self.aggregate.connections.add(
+                  key, self.url_connection, self.timeout)
         else:
             try:
                 self.url_connection.close()
