@@ -39,6 +39,10 @@ import linkcheck.containers
 import linkcheck.log
 import linkcheck.httplib2
 import linkcheck.HtmlParser.htmlsax
+from const import WARN_URL_EFFECTIVE_URL, WARN_URL_UNICODE_DOMAIN, \
+    WARN_URL_UNNORMED, WARN_URL_ERROR_GETTING_CONTENT, \
+    WARN_URL_ANCHOR_NOT_FOUND, WARN_URL_WARNREGEX_FOUND, \
+    WARN_URL_CONTENT_TOO_LARGE
 
 # helper alias
 unicode_safe = linkcheck.strformat.unicode_safe
@@ -66,9 +70,7 @@ def url_norm (url):
 
 
 class UrlBase (object):
-    """
-    An URL with additional information like validity etc.
-    """
+    """An URL with additional information like validity etc."""
 
     def __init__ (self, base_url, recursion_level, aggregate,
                   parent_url = None, base_ref = None,
@@ -147,10 +149,8 @@ class UrlBase (object):
         self.checktime = 0
         # connection object
         self.url_connection = None
-        # data of url content
+        # data of url content,  (data == None) means no data is available
         self.data = None
-        # if data is filled
-        self.has_content = False
         # cache keys, are set by build_url() calling set_cache_keys()
         self.cache_url_key = None
         self.cache_content_key = None
@@ -293,9 +293,9 @@ class UrlBase (object):
             effectiveurl = urlparse.urlunsplit(self.urlparts)
             if self.url != effectiveurl:
                 self.add_warning(_("Effective URL %r.") % effectiveurl,
-                                 tag="url-effective-url")
+                                 tag=WARN_URL_EFFECTIVE_URL)
                 self.url = effectiveurl
-        except tuple(linkcheck.checker.ExcSyntaxList), msg:
+        except tuple(linkcheck.checker.const.ExcSyntaxList), msg:
             self.set_result(unicode_safe(msg), valid=False)
             return
         self.set_cache_keys()
@@ -312,11 +312,11 @@ class UrlBase (object):
                           is not yet widely supported. You should use
                           the URL %(idna_url)r instead.""") % \
                           {"url": self.base_url, "idna_url": base_url},
-                          tag="url-unicode-domain")
+                          tag=WARN_URL_UNICODE_DOMAIN)
         elif self.base_url != base_url:
             self.add_warning(
               _("Base URL is not properly normed. Normed URL is %(url)s.") %
-               {'url': base_url}, tag="url-unnormed")
+               {'url': base_url}, tag=WARN_URL_UNNORMED)
         # make url absolute
         if self.base_ref:
             # use base reference as parent url
@@ -359,21 +359,23 @@ class UrlBase (object):
             self.port = int(self.port)
 
     def check (self):
-        """
-        Main check function for checking this URL.
-        """
+        """Main check function for checking this URL."""
         if self.aggregate.config["trace"]:
             linkcheck.trace.trace_on()
         try:
-            self.local_check()
-        except (socket.error, select.error):
-            # on Unix, ctrl-c can raise
-            # error: (4, 'Interrupted system call')
-            etype, value = sys.exc_info()[:2]
-            if etype == errno.EINTR:
-                raise KeyboardInterrupt(value)
-            else:
-                raise
+            try:
+                self.local_check()
+            except (socket.error, select.error):
+                # on Unix, ctrl-c can raise
+                # error: (4, 'Interrupted system call')
+                etype, value = sys.exc_info()[:2]
+                if etype == errno.EINTR:
+                    raise KeyboardInterrupt(value)
+                else:
+                    raise
+        finally:
+            # close/release possible open connection
+            self.close_connection()
 
     def add_country_info (self):
         """
@@ -384,9 +386,7 @@ class UrlBase (object):
             self.add_info(_("URL is located in %s.") % _(country))
 
     def local_check (self):
-        """
-        Local check function can be overridden in subclasses.
-        """
+        """Local check function can be overridden in subclasses."""
         assert None == linkcheck.log.debug(linkcheck.LOG_CHECK,
             "Checking %s", self)
         # start time for check
@@ -404,7 +404,7 @@ class UrlBase (object):
             self.add_country_info()
             if self.aggregate.config["anchors"]:
                 self.check_anchors()
-        except tuple(linkcheck.checker.ExcList):
+        except tuple(linkcheck.checker.const.ExcList):
             value = self.handle_exception()
             # make nicer error msg for unknown hosts
             if isinstance(value, socket.error) and value[0] == -2:
@@ -421,7 +421,7 @@ class UrlBase (object):
                 "checking content")
             try:
                 self.check_content(warningregex)
-            except tuple(linkcheck.checker.ExcList):
+            except tuple(linkcheck.checker.const.ExcList):
                 value = self.handle_exception()
                 self.set_result(unicode_safe(value), valid=False)
 
@@ -432,12 +432,10 @@ class UrlBase (object):
                 self.parse_url()
             # check content size
             self.check_size()
-        except tuple(linkcheck.checker.ExcList):
+        except tuple(linkcheck.checker.const.ExcList):
             value = self.handle_exception()
             self.add_warning(_("could not get content: %r") % str(value),
-                            tag="url-error-getting-content")
-        # close
-        self.close_connection()
+                            tag=WARN_URL_ERROR_GETTING_CONTENT)
 
     def close_connection (self):
         """
@@ -461,7 +459,7 @@ class UrlBase (object):
         assert None == linkcheck.log.debug(linkcheck.LOG_CHECK,
             "exception %s", traceback.format_tb(tb))
         # note: etype must be the exact class, not a subclass
-        if (etype in linkcheck.checker.ExcNoCacheList) or \
+        if (etype in linkcheck.checker.const.ExcNoCacheList) or \
            (etype == socket.error and value[0]==errno.EBADF) or \
             not value:
             # EBADF occurs when operating on an already socket
@@ -520,14 +518,17 @@ class UrlBase (object):
             return True
         if not (self.is_http() or self.is_file()):
             return True
-        h = linkcheck.linkparse.MetaRobotsFinder(self.get_content())
-        p = linkcheck.HtmlParser.htmlsax.parser(h)
-        h.parser = p
-        p.feed(self.get_content())
-        p.flush()
-        h.parser = None
-        p.handler = None
-        return h.follow
+        # construct parser object
+        handler = linkcheck.linkparse.MetaRobotsFinder()
+        parser = linkcheck.HtmlParser.htmlsax.parser(handler)
+        handler.parser = parser
+        # parse
+        parser.feed(self.get_content())
+        parser.flush()
+        # break cyclic dependencies
+        handler.parser = None
+        parser.handler = None
+        return handler.follow
 
     def check_anchors (self):
         """
@@ -540,19 +541,20 @@ class UrlBase (object):
             return
         assert None == linkcheck.log.debug(linkcheck.LOG_CHECK,
             "checking anchor %r", self.anchor)
-        h = linkcheck.linkparse.LinkFinder(self.get_content(),
+        handler = linkcheck.linkparse.LinkFinder(self.get_content(),
                                    tags={'a': [u'name'], None: [u'id']})
-        p = linkcheck.HtmlParser.htmlsax.parser(h)
-        h.parser = p
-        p.feed(self.get_content())
-        p.flush()
-        h.parser = None
-        p.handler = None
-        for cur_anchor, line, column, name, base in h.urls:
-            if cur_anchor == self.anchor:
-                return
+        parser = linkcheck.HtmlParser.htmlsax.parser(handler)
+        handler.parser = parser
+        # parse
+        parser.feed(self.get_content())
+        parser.flush()
+        # break cyclic dependencies
+        handler.parser = None
+        parser.handler = None
+        if [x for x in handler.urls if x[0] == self.anchor]:
+            return
         self.add_warning(_("Anchor #%s not found.") % self.anchor,
-                         tag="url-anchor-not-found")
+                         tag=WARN_URL_ANCHOR_NOT_FOUND)
 
     def set_extern (self, url):
         """
@@ -593,12 +595,11 @@ class UrlBase (object):
         """
         Precondition: url_connection is an opened URL.
         """
-        if not self.has_content:
+        if self.data is None:
             t = time.time()
             self.data = self.url_connection.read()
             self.dltime = time.time() - t
             self.dlsize = len(self.data)
-            self.has_content = True
         return self.data
 
     def check_content (self, warningregex):
@@ -611,7 +612,7 @@ class UrlBase (object):
         match = warningregex.search(self.get_content())
         if match:
             self.add_warning(_("Found %r in link contents.") % match.group(),
-                             tag="url-warnregex-found")
+                             tag=WARN_URL_WARNREGEX_FOUND)
 
     def check_size (self):
         """
@@ -624,7 +625,7 @@ class UrlBase (object):
                    _("Content size %(dlsize)s is larger than %(maxbytes)s.") %
                         {"dlsize": linkcheck.strformat.strsize(self.dlsize),
                          "maxbytes": linkcheck.strformat.strsize(maxbytes)},
-                          tag="url-content-too-large")
+                          tag=WARN_URL_CONTENT_TOO_LARGE)
 
     def parse_url (self):
         """
@@ -650,23 +651,25 @@ class UrlBase (object):
         """
         assert None == linkcheck.log.debug(linkcheck.LOG_CHECK,
             "Parsing HTML %s", self)
-        h = linkcheck.linkparse.LinkFinder(self.get_content())
-        p = linkcheck.HtmlParser.htmlsax.parser(h)
-        h.parser = p
-        p.feed(self.get_content())
-        p.flush()
-        h.parser = None
-        p.handler = None
-        for url, line, column, name, codebase in h.urls:
+        # construct parser object
+        handler = linkcheck.linkparse.LinkFinder(self.get_content())
+        parser = linkcheck.HtmlParser.htmlsax.parser(handler)
+        handler.parser = parser
+        # parse
+        parser.feed(self.get_content())
+        parser.flush()
+        # break cyclic dependencies
+        handler.parser = None
+        parser.handler = None
+        for url, line, column, name, codebase in handler.urls:
             if codebase:
                 base_ref = codebase
             else:
-                base_ref = h.base_ref
+                base_ref = handler.base_ref
             base_ref = linkcheck.url.url_norm(base_ref)[0]
             url_data = linkcheck.checker.get_url_from(url,
                   self.recursion_level+1, self.aggregate, parent_url=self.url,
-                  base_ref=base_ref, line=line, column=column, name=name,
-                  assume_local=False)
+                  base_ref=base_ref, line=line, column=column, name=name)
             self.aggregate.urlqueue.put(url_data)
 
     def parse_opera (self):
@@ -677,8 +680,7 @@ class UrlBase (object):
             "Parsing Opera bookmarks %s", self)
         name = ""
         lineno = 0
-        lines = self.get_content().splitlines()
-        for line in lines:
+        for line in self.get_content().splitlines():
             lineno += 1
             line = line.strip()
             if line.startswith("NAME="):
@@ -688,8 +690,7 @@ class UrlBase (object):
                 if url:
                     url_data = linkcheck.checker.get_url_from(url,
                               self.recursion_level+1, self.aggregate,
-                              parent_url=self.url, line=lineno, name=name,
-                              assume_local=False)
+                              parent_url=self.url, line=lineno, name=name)
                     self.aggregate.urlqueue.put(url_data)
                 name = ""
 
@@ -708,8 +709,7 @@ class UrlBase (object):
                 continue
             url_data = linkcheck.checker.get_url_from(line,
                               self.recursion_level+1, self.aggregate,
-                              parent_url=self.url, line=lineno,
-                              assume_local=False)
+                              parent_url=self.url, line=lineno)
             self.aggregate.urlqueue.put(url_data)
 
     def parse_css (self):
@@ -719,15 +719,16 @@ class UrlBase (object):
         assert None == linkcheck.log.debug(linkcheck.LOG_CHECK,
             "Parsing CSS %s", self)
         lineno = 0
-        for line in self.get_content().splitlines():
+        linkfinder = linkcheck.linkparse.css_url_re.finditer
+        strip_comments = linkcheck.linkparse.strip_c_comments
+        for line in strip_comments(self.get_content()).splitlines():
             lineno += 1
-            for mo in linkcheck.linkparse.css_url_re.finditer(line):
+            for mo in linkfinder(line):
                 column = mo.start("url")
                 url = linkcheck.strformat.unquote(mo.group("url").strip())
                 url_data = linkcheck.checker.get_url_from(url,
                              self.recursion_level+1, self.aggregate,
-                             parent_url=self.url, line=lineno, column=column,
-                             assume_local=False)
+                             parent_url=self.url, line=lineno, column=column)
                 self.aggregate.urlqueue.put(url_data)
 
     def serialized (self):
