@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2005  Bastian Kleineidam
+# Copyright (C) 2005-2007 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -38,6 +38,21 @@ def h ():
 import warnings
 import signal
 import os
+import sys
+import time
+
+
+def update_func_meta (fake_func, real_func):
+    """
+    Set meta information (eg. __doc__) of fake function to that
+    of the real function.
+    @return fake_func
+    """
+    fake_func.__module__ = real_func.__module__
+    fake_func.__name__ = real_func.__name__
+    fake_func.__doc__ = real_func.__doc__
+    fake_func.__dict__.update(real_func.__dict__)
+    return fake_func
 
 
 def deprecated (func):
@@ -52,11 +67,7 @@ def deprecated (func):
         warnings.warn("Call to deprecated function %s." % func.__name__,
                       category=DeprecationWarning)
         return func(*args, **kwargs)
-    newfunc.__name__ = func.__name__
-    if func.__doc__ is not None:
-        newfunc.__doc__ += func.__doc__
-    newfunc.__dict__.update(func.__dict__)
-    return newfunc
+    return update_func_meta(newfunc, func)
 
 
 def signal_handler (signal_number):
@@ -84,36 +95,27 @@ def signal_handler (signal_number):
     return newfunc
 
 
-def _synchronized (lock, func):
+def synchronize (lock, func):
     """
-    Call function with aqcuired lock.
+    Return synchronized function acquiring the given lock.
     """
     def newfunc (*args, **kwargs):
         """
         Execute function synchronized.
         """
-        lock.acquire(True) # blocking
+        lock.acquire()
         try:
             return func(*args, **kwargs)
         finally:
             lock.release()
-    newfunc.__name__ = func.__name__
-    if func.__doc__ is not None:
-        newfunc.__doc__ += func.__doc__
-    newfunc.__dict__.update(func.__dict__)
-    return newfunc
+    return update_func_meta(newfunc, func)
 
 
 def synchronized (lock):
     """
     A decorator calling a function with aqcuired lock.
     """
-    def newfunc (function):
-        """
-        Execute function synchronized.
-        """
-        return _synchronized(lock, function)
-    return newfunc
+    return lambda func: synchronize(lock, func)
 
 
 def notimplemented (func):
@@ -126,8 +128,71 @@ def notimplemented (func):
         Raise NotImplementedError
         """
         raise NotImplementedError("%s not implemented" % func.__name__)
-    newfunc.__name__ = func.__name__
-    if func.__doc__ is not None:
-        newfunc.__doc__ = func.__doc__
-    newfunc.__dict__.update(func.__dict__)
-    return newfunc
+    return update_func_meta(newfunc, func)
+
+
+def timeit (func, log, limit):
+    """
+    Print execution time of the function. For quick'n'dirty profiling.
+    """
+    def newfunc (*args, **kwargs):
+        """
+        Execute function and print execution time.
+        """
+        t = time.time()
+        res = func(*args, **kwargs)
+        duration = time.time() - t
+        if duration > limit:
+            print >> log, func.__name__, "took %0.2f seconds" % duration
+            print >> log, args
+            print >> log, kwargs
+        return res
+    return update_func_meta(newfunc, func)
+
+
+def timed (log=sys.stderr, limit=2.0):
+    return lambda func: timeit(func, log, limit)
+
+
+class memoized (object):
+    """
+    Decorator that caches a function's return value each time it is called.
+    If called later with the same arguments, the cached value is returned, and
+    not re-evaluated.
+    """
+    def __init__(self, func):
+        self.func = func
+        self.cache = {}
+
+    def __call__(self, *args):
+        try:
+            return self.cache[args]
+        except KeyError:
+            self.cache[args] = value = self.func(*args)
+            return value
+        except TypeError:
+            # uncachable -- for instance, passing a list as an argument.
+            # Better to not cache than to blow up entirely.
+            return self.func(*args)
+
+    def __repr__(self):
+        """Return the function's docstring."""
+        return self.func.__doc__
+
+
+class curried (object):
+    """
+    Decorator that returns a function that keeps returning functions
+    until all arguments are supplied; then the original function is
+    evaluated.
+    """
+    def __init__(self, func, *a):
+        self.func = func
+        self.args = a
+
+    def __call__(self, *a):
+        args = self.args + a
+        if len(args) < self.func.func_code.co_argcount:
+            return curried(self.func, *args)
+        else:
+            return self.func(*args)
