@@ -14,18 +14,19 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-"""Aggregate needed object instances for checker threads."""
+"""
+Aggregate needed object instances for checker threads.
+"""
 import linkcheck.log
 import linkcheck.director
 import logger
 import status
 import checker
+import cleanup
 
 
 class Aggregate (object):
-    """
-    Store thread-safe data collections for checker threads.
-    """
+    """Store thread-safe data collections for checker threads."""
 
     def __init__ (self, config, urlqueue, connections, cookies, robots_txt):
         self.config = config
@@ -37,13 +38,14 @@ class Aggregate (object):
         self.threads = []
 
     def start_threads (self):
-        """
-        Spawn threads for URL checking and status printing.
-        """
+        """Spawn threads for URL checking and status printing."""
         if self.config["status"]:
             t = status.Status(self.urlqueue)
             t.start()
             self.threads.append(t)
+        t = cleanup.Cleanup(self.connections)
+        t.start()
+        self.threads.append(t)
         num = self.config["threads"]
         if num >= 1:
             for i in xrange(num):
@@ -54,9 +56,7 @@ class Aggregate (object):
             checker.check_url(self.urlqueue, self.logger)
 
     def abort (self):
-        """
-        Empty the URL queue.
-        """
+        """Empty the URL queue."""
         self.urlqueue.do_shutdown()
         try:
             self.urlqueue.join(timeout=self.config["timeout"])
@@ -64,15 +64,15 @@ class Aggregate (object):
             linkcheck.log.warn(linkcheck.LOG_CHECK, "Abort timed out")
 
     def remove_stopped_threads (self):
+        "Remove the stopped threads from the internal thread list."""
         self.threads = [t for t in self.threads if t.isAlive()]
 
     def finish (self):
-        """
-        Wait for checker threads to finish.
-        """
+        """Wait for checker threads to finish."""
         assert self.urlqueue.empty()
         for t in self.threads:
             t.stop()
             t.join(2)
             if t.isAlive():
                 linkcheck.log.warn(linkcheck.LOG_CHECK, "Thread %s still active", t)
+        self.connections.clear()
