@@ -894,7 +894,7 @@ class HTTPConnection:
         #                  isclosed() status to become true.
         #
         if self.__state != _CS_REQ_SENT or self.__response:
-            msg = "State %s, Reponse %s" % (self.__state, self.__response)
+            msg = "State %s, Response %s" % (self.__state, self.__response)
             raise ResponseNotReady(msg)
 
         if self.debuglevel > 0:
@@ -1081,6 +1081,7 @@ class FakeSocket(SharedSocketClient):
     def close(self):
         SharedSocketClient.close(self)
         self._sock = self.__class__._closedsocket()
+        self._ssl = None
 
     def makefile(self, mode, bufsize=None):
         if mode != 'r' and mode != 'rb':
