@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2000-2006 Bastian Kleineidam
+# Copyright (C) 2000-2007 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -27,6 +27,10 @@ import gettext
 supported_languages = ['en']
 default_language = 'en'
 default_encoding = locale.getpreferredencoding()
+# It can happen that the preferrec encoding is not determinable, which
+# means the function returned None. Fall back to ASCII in this case.
+if default_encoding is None:
+    default_encoding = "ascii"
 
 def install_builtin (translator, do_unicode):
     """
