@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2000-2006 Bastian Kleineidam
+# Copyright (C) 2000-2007 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -53,14 +53,12 @@ class CSVLogger (linkcheck.logger.Logger):
         Write checking start info as csv comment.
         """
         super(CSVLogger, self).start_output()
-        if self.fd is None:
-            return
         self.starttime = time.time()
         row = []
         if self.has_part("intro"):
-            self.comment(_("created by %s at %s") %
-                         (linkcheck.configuration.AppName,
-                          linkcheck.strformat.strtime(self.starttime)))
+            self.comment(_("created by %(app)s at %(time)s") %
+                        {"app": linkcheck.configuration.AppName,
+                         "time": linkcheck.strformat.strtime(self.starttime)})
             self.comment(_("Get the newest version at %(url)s") %
                          {'url': linkcheck.configuration.Url})
             self.comment(_("Write comments and bugs to %(email)s") %
@@ -96,8 +94,6 @@ class CSVLogger (linkcheck.logger.Logger):
         """
         Write csv formatted url check info.
         """
-        if self.fd is None:
-            return
         row = []
         for s in [url_data.base_url or u"", url_data.recursion_level,
                url_data.parent_url or u"", url_data.base_ref or u"",
@@ -120,12 +116,10 @@ class CSVLogger (linkcheck.logger.Logger):
         """
         Write end of checking info as csv comment.
         """
-        if self.fd is None:
-            return
         self.stoptime = time.time()
         if self.has_part("outro"):
             duration = self.stoptime - self.starttime
-            self.comment(_("Stopped checking at %s (%s)") %
-                         (linkcheck.strformat.strtime(self.stoptime),
-                          linkcheck.strformat.strduration_long(duration)))
+            self.comment(_("Stopped checking at %(time)s (%(duration)s)") %
+                 {"time": linkcheck.strformat.strtime(self.stoptime),
+                  "duration": linkcheck.strformat.strduration_long(duration)})
         self.close_fileoutput()
