@@ -77,6 +77,7 @@ class TestCookies (unittest.TestCase):
     def test_netscape_cookie4 (self):
         data = (
             ("Foo", "Bar\""),
+            ("Domain", "localhost"),
             ("Port", "100,555,76"),
         )
         parts = ['%s="%s"' % (key, value) for key, value in data]
@@ -86,6 +87,22 @@ class TestCookies (unittest.TestCase):
         path = "/"
         cookie = linkcheck.cookies.NetscapeCookie(value, scheme, host, path)
 
+    def test_netscape_cookie5 (self):
+        data = (
+            ("Foo", "Bar"),
+            ("Domain", "imadoofus.org"),
+            ("Expires", "Wed, 12-Dec-2001 19:27:57 GMT"),
+            ("Path", "/"),
+        )
+        # note: values are without quotes
+        parts = ['%s=%s' % (key, value) for key, value in data]
+        value = "; ".join(parts)
+        scheme = "http"
+        host = "imadoofus.org"
+        path = "/"
+        cookie = linkcheck.cookies.NetscapeCookie(value, scheme, host, path)
+        self.assert_(cookie.is_expired())
+
     def test_rfc_cookie1 (self):
         data = (
             ("Foo", "Bar"),
